@@ -5,8 +5,8 @@ __author__ = ", ".join(["Shyue Ping Ong", "Anubhav Jain", "Geoffroy Hautier",
                         "Sai Jayaraman", "Michael Kocher", "Dan Gunter",
                         "Shreyas Cholia", "Vincent L Chevrier",
                         "Rickard Armiento"])
-__date__ = "Sep 23 2014"
-__version__ = "3.0.4"
+__date__ = "Oct 2 2014"
+__version__ = "3.0.5"
 
 #Useful aliases for commonly used objects and modules.
 
