@@ -10,13 +10,8 @@ import time
 import collections
 import warnings
 import shutil
+
 from six.moves import map, cPickle as pickle
-
-try:
-    from pydispatch import dispatcher
-except ImportError:
-    pass
-
 from monty.io import FileLock
 from pymatgen.util.string_utils import pprint_table
 from .tasks import Dependency, Status, Node, Task, ScfTask, PhononTask, TaskManager
@@ -24,6 +19,11 @@ from .utils import Directory, Editor
 from .abiinspect import yaml_read_irred_perts
 from .workflows import Workflow, BandStructureWorkflow, PhononWorkflow, G0W0_Workflow, QptdmWorkflow
 
+try:
+    from pydispatch import dispatcher
+except ImportError:
+    pass
+
 import logging
 logger = logging.getLogger(__name__)
 
@@ -106,6 +106,29 @@ class AbinitFlow(Node):
         #for task in self.iflat_tasks():
         #    slots[task] = {s: [] for s in work.S_ALL}
 
+    # This is needed for fireworks although Node.__str__ and __repr__ are much more readable.
+    #def __repr__(self):
+    #    return self.workdir
+
+    #def __str__(self):
+    #    return repr(self)
+
+    def as_dict(self, **kwargs):
+        """
+        JSON serialization, note that we only need to save 
+        a string with the working directory since the object will be 
+        reconstructed from the pickle file located in workdir
+        """
+        return {"workdir": self.workdir}
+
+    # This is needed for fireworks.
+    to_dict = as_dict
+
+    @classmethod
+    def from_dict(cls, d, **kwargs):
+        """Reconstruct the flow from the pickle file."""
+        return cls.pickle_load(d["workdir"], **kwargs)
+
     def set_workdir(self, workdir, chroot=False):
         """
         Set the working directory. Cannot be set more than once unless chroot is True
@@ -150,9 +173,9 @@ class AbinitFlow(Node):
                 err_msg = "Cannot find %s inside directory %s" % (cls.PICKLE_FNAME, filepath)
                 raise ValueError(err_msg)
 
-        #with FileLock(filepath) as lock:
-        with open(filepath, "rb") as fh:
-            flow = pickle.load(fh)
+        with FileLock(filepath):
+            with open(filepath, "rb") as fh:
+                flow = pickle.load(fh)
 
         # Check if versions match.
         if flow.VERSION != cls.VERSION:
@@ -405,7 +428,7 @@ class AbinitFlow(Node):
             #todo
             if task.fix_abicritical():
                 task.reset_from_scratch()
-                # task.set_status(task.S_READY)
+                # task.set_status(Task.S_READY)
             else:
                 info_msg = 'We encountered an abi critial envent that could not be fixed'
                 logger.warning(info_msg)
@@ -436,7 +459,7 @@ class AbinitFlow(Node):
                     return False
             else:
                 for error in task.queue_errors:
-                    print('fixing :' + str(error))
+                    logger.info('fixing : %s' % str(error))
                     if isinstance(error, NodeFailureError):
                         # if the problematic node is know exclude it
                         if error.nodes is not None:
@@ -882,6 +905,46 @@ class AbinitFlow(Node):
             print("receiver -->", rec)
         print("*** end live receivers ***")
 
+    def rapidfire(self, check_status=False, **kwargs):
+        """
+        Use PyLauncher to submits tasks in rapidfire mode.
+        kwargs contains the options passed to the launcher.
+
+        Return the number of tasks submitted.
+        """
+        from .launcher import PyLauncher
+
+        if check_status:
+            self.check_status()
+
+        return PyLauncher(self, **kwargs).rapidfire()
+
+    def make_scheduler(self, **kwargs):
+        """
+        Build a return a scheduler to run the flow.
+
+        kwargs:
+            if empty we use the user configuration file.
+            if filepath in kwargs we init the scheduler from file.
+            else pass **kwargs to PyFlowScheduler.__init__
+        """
+        from .launcher import PyFlowScheduler
+
+        if not kwargs:
+            # User config if kwargs is empty
+            sched = PyFlowScheduler.from_user_config()
+        else:
+            # Use from_file if filepath if present, else call __init__
+            filepath == kwargs.pop("filepath", None)
+            if filepath is not None:
+                assert not kwargs
+                sched = PyFlowScheduler.from_file(filepath)
+            else:
+                sched = PyFlowScheduler.from_file(**kwargs)
+
+        sched.add_flow(self)
+        return sched
+
 
 class G0W0WithQptdmFlow(AbinitFlow):
     """
