@@ -1,20 +1,20 @@
-from __future__ import division, print_function
-
+# coding: utf-8
 """Strategy objects for creating ABINIT calculations."""
+from __future__ import unicode_literals, division, print_function
 
 import sys
 import os
 import abc
 import collections
 import copy
+import six
 import numpy as np
 
-from pymatgen.util.string_utils import str_aligned, str_delimited, is_string
-from pymatgen.io.abinitio.abiobjects import Electrons
-from pymatgen.io.abinitio.pseudos import PseudoTable
-import six
-from six.moves import map
-from six.moves import zip
+from six.moves import map, zip
+from monty.string import is_string
+from pymatgen.util.string_utils import str_aligned, str_delimited
+from .abiobjects import Electrons
+from .pseudos import PseudoTable
 
 import logging
 logger = logging.getLogger(__name__)
@@ -120,6 +120,7 @@ class AbstractStrategy(six.with_metaclass(abc.ABCMeta, object)):
         return self.pseudos.allpaw
 
     def num_valence_electrons(self):
+        """Number of valence electrons computed from the pseudos and the structure."""
         return num_valence_electrons(self.pseudos, self.structure)
 
     #@abc.abstractproperty
@@ -861,7 +862,7 @@ class OpticInput(object):
             self.vars[k] = v
 
     def __init__(self, zcut, wstep, wmax, scissor, sing_tol, linear_components,
-                nonlinear_components=None, ddk_files=None, wfk=None):
+                 nonlinear_components=None, ddk_files=None, wfk=None):
 
         self.vars = vars = collections.OrderedDict(*self.VAR_NAMES)
 
@@ -881,7 +882,7 @@ class OpticInput(object):
         vars["num_lin_comp"] = len(linear_components)
         vars["lin_comp"] = " ".join(str(c) for c in linear_components)
 
-        vars["num_nonlin_comp"] = len(non_linear_components)
+        vars["num_nonlin_comp"] = len(nonlinear_components)
         vars["nonlin_comp"] = " ".join(str(c) for c in nonlinear_components)
 
     def __init__(self, string):
